package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````D"(``#0```!,P0```````#0`(``,
M`"@`&P`:``8````T````-````#0```"``0``@`$```0````$`````P```+0!
M``"T`0``M`$``!,````3````!`````$````!````````````````````N!$`
M`+@1```$`````!````$`````(````"`````@```,,0``##$```4`````$```
M`0````!@````8````&```*A.``"H3@``!``````0```!````V+T``-B]``#8
MO0``0`(``%0"```&`````!````(```#@O0``X+T``."]```(`0``"`$```8`
M```$````!````,@!``#(`0``R`$``&P```!L````!`````0```!3Y71D[`$`
M`.P!``#L`0``*````"@````$````!````%#E=&1PH```<*```'"@```<`0``
M'`$```0````$````4>5T9```````````````````````````!@```!````!2
MY71DV+T``-B]``#8O0``*`(``"@"```$`````0```"]L:6(O;&0M;&EN=7@N
M<V\N,@``!````!0````#````1TY5`-NQ([BALC>N<E#M62&JRUL.OKRA!```
M`!@````%````1TY5``$``<`$`````0````(``<`$``````````0````0````
M`0```$=.50``````!`````0`````````*P```$0````(````"``````0$`0E
M0`2`*`$`!:"&`(2`@0`""R@$"#B`$D&*```(1```````````````10``````
M````````1@````````!'````2`````````!)`````````$L`````````````
M`$P```!-`````````$\```!0````4@````````!3````5````%4`````````
M`````````````````````%8```!7````6````%D```!:``````````````!<
M`````````%T``````````````(D'<--K&IY0H^#[29E/PYOC1\8!9J_,9D-%
MU>R[XY)\LP&+;UCH[>QOQ=\?%8PES"[%F[9K"4/6(?_D#ONA;&##Y3\L#3J7
M"\_>1RW9<5@<?ZF<F^&G`@I"^M>':W^:?#-BV^W49-1\K4OCP```````````
M``````````"M`@`````````````2````%P(`````````````$@````("````
M`````````!(````9`0`````````````2````8P$`````````````$@```.(`
M`````````````!(```#+`0`````````````2````/0(`````````````$@``
M`/@``````````````!(````!```````````````@````)P(`````````````
M$@```(("`````````````!(```#0`@`````````````2````F@``````````
M````$@```,,``````````````!(````R`0`````````````2````T@$`````
M````````$@```/T!`````````````!(````0```````````````@````[0``
M````````````$@```!X!`````````````!(```"8`@`````````````2````
M+```````````````(````$P"`````````````!(````(`@`````````````2
M````B0(`````````````$@```$`!`````````````!(```""`0``````````
M```6````B@``````````````$@```$8``````````````!(```"R````````
M```````2````HP``````````````$@```+$!`````````````!(```!E`@``
M```````````1````GP(`````````````$@```/`!`````````````!(```#:
M`0`````````````2````CP,`````````````$@```",!`````````````!(`
M``"1`@`````````````2````R`(`````````````$0```,(!````````````
M`!(````+`0`````````````2````>P$`````````````$@```%<`````````
M`````!(```#B`@`````````````2````]P$`````````````$@```.D!````
M`````````!(```!+`@`````````````2````'@(`````````````$@```.$!
M`````````````!(```!.`0`````````````2````;P$`````````````$@``
M`"\"`````````````!(```#&`@`````````````1````;`(`````````````
M$@```+X"`````````````!(```!N```````````````1````TP``````````
M````$0```&,``````````````!(```![```````````````2````NP$`````
M````````$@```%,"`````````````!(```"I`0`````````````2````I@(`
M````````````$@```',"`````````````"(```"D`0`````````````2````
M$00``!3````$````$0`7`',#``"03@``$0(``!(`#@`C!```("\``/P#```2
M``X`&P0``)`S```U````$@`.`!D#``!@+0``.````!(`#@!G`P``H"T``'0!
M```2``X`ZP,``!C`````````$``7`-D#```LP````````!``&`!#`P``(#,`
M`&$````2``X`)@,```!@```$````$0`0`)@#``#`/P``RP```!(`#@#0`P``
M@$P``%`````2``X`"`,``"`K```%````$@`.`*0#````P````````!``%P`$
M!```,"L``"<"```2``X`\@,``)`U``#%````$@`.`+P#```0*@``-````!(`
M#@"F`P```,`````````@`!<`W@,``&`V```Z!P``$@`.`,0#```8P```````
M`!``&`!]`P``8#4``"T````2``X`40,``%`J``#-````$@`.`+$#``#03```
MO`$``!(`#@!@`@``0"```$T"```2``X`J@,``)`B```L````$@`.`"T#``"@
M/0``%@(``!(`#@"5`0``!&````0````1`!```%]?9VUO;E]S=&%R=%]?`%])
M5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-7W)E9VES=&5R5$U#;&]N
M951A8FQE`%!E<FQ?871F;W)K7VQO8VL`4&5R;%]M9U]S970`4&5R;%]N97=8
M4P!03%]D;U]U;F1U;7``4&5R;%]S>7-?:6YI=#,`8F]O=%]$>6YA3&]A9&5R
M`'!E<FQ?<G5N`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?;F5W6%-?9FQA9W,`4&5R
M;%]G=E]F971C:'!V`%!,7VUE;6]R>5]W<F%P`'!E<FQ?<&%R<V4`<&5R;%]A
M;&QO8P!097)L7V%T9F]R:U]U;FQO8VL`<&5R;%]D97-T<G5C=`!P97)L7V9R
M964`4&5R;%]S=E]S971P=FX`4&5R;%]S=E]S971P=@!097)L7W-Y<U]T97)M
M`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?9V5T7W-V`%!E<FQ?<V%F97-Y
M<VUA;&QO8P!03%]C=7)R96YT7V-O;G1E>'0`7TE/7W-T9&EN7W5S960`97AI
M=`!L<V5E:S8T`')E861D:7(V-`!S=')D=7``8VQO<V5D:7(`;W!E;C8T`'-T
M<G)C:'(`=6YL:6YK`&UE;6UO=F4`<W1R=&]K`'-T<FQE;@!R;61I<@!R96%D
M`&UK9&ER`%]?=F9P<FEN=&9?8VAK`&=E='!I9`!R96%D;&EN:P!R96%L;&]C
M`%]?<W!R:6YT9E]C:&L`7U]F<')I;G1F7V-H:P!L<W1A=#8T`%]?;&EB8U]S
M=&%R=%]M86EN`'-T9&5R<@!M96UC:'(`7U]C>&%?9FEN86QI>F4`<W1R8VAR
M`&]P96YD:7(`9V5T=6ED`&%C8V5S<P!M96UC<'D`<W1R8VUP`%]?97)R;F]?
M;&]C871I;VX`<W1R;F-M<`!?7V5N=FER;VX`7U]R96=I<W1E<E]A=&9O<FL`
M7U]S=&%C:U]C:&M?9F%I;`!L:6)P97)L+G-O`&QI8F,N<V\N-@!P87)?8W5R
M<F5N=%]E>&5C`'!A<E]B87-E;F%M90!?9G!?:'<`6%-?26YT97)N86QS7U!!
M4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A
M<E]D:7)N86UE`'-H85]F:6YA;`!G971?=7-E<FYA;65?9G)O;5]G971P=W5I
M9`!P87)?8VQE86YU<`!?7V1A=&%?<W1A<G0`<VAA7W5P9&%T90!X<U]I;FET
M`%]?8G-S7W-T87)T`'-H85]I;FET`%]E;F0`<&%R7VUK=&UP9&ER`%]E9&%T
M80!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`;7E?<&%R7W!L`'!A
M<E]D:64`<&%R7VEN:71?96YV`$=,24)#7S(N,2XS`$=,24)#7S(N,S0`1TQ)
M0D-?,BXT`$=,24)#7S(N,@!'3$E"0U\R+C,S`$=,24)#7S(N,RXR`$=,24)#
M7S(N,RXT`$=,24)#7S(N,0!'3$E"0U\R+C``+W5S<B]L:6(O<&5R;#4O-2XS
M."]C;W)E7W!E<FPO0T]210`````"``(``@`!``$``0`#``0``0`!``(``@`%
M``$``0`!``(``@`!``$``@`"``$`!@`$``(``0`!``$``0`!``$`!P`"``(`
M`@`"``(``0`"``(``@`!``(``0`(``(``@`&``(``@`!``$`!``"``(``@`!
M``$``0`!``(`"0`#``(`"@`"``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`"0#^`@``$`````````!S
M'VD)```*`#`$```0````M)&6!@``"0`\!```$````!1I:0T```@`1P0``!``
M```2:6D-```'`%$$```0````LY&6!@``!@!;!```$````'(9:0D```4`9@0`
M`!````!T&6D)```$`'($```0````$6EI#0```P!^!```$````!!I:0T```(`
MB`0```````#8O0``"````-R]```(````_+\```@````$P```"````!3````(
M````^+X```8!``#\O@``!@(```"_```&`P``!+\```8$```(OP``!@4```R_
M```&!@``$+\```8'```4OP``!@@``!B_```&"0``'+\```8*```@OP``!@L`
M`"2_```&#```*+\```8-```LOP``!@X``#"_```&#P``-+\```80```XOP``
M!A$``#R_```&$@``0+\```83``!$OP``!A0``$B_```&%0``3+\```86``!0
MOP``!A<``%2_```&&```6+\```89``!<OP``!AH``&"_```&&P``9+\```X<
M``!HOP``!AT``&R_```&'@``<+\```8?``!TOP``!B```'B_```&(0``?+\`
M``8B``"`OP``!B,``(2_```&)```B+\```8E``",OP``!B8``)"_```&)P``
ME+\```8H``"8OP``!BD``)R_```&*@``H+\```8K``"DOP``!BP``*B_```&
M+0``K+\```8N``"POP``!B\``+2_```&,```N+\```8Q``"\OP``!C(``,"_
M```&,P``Q+\```8T``#(OP``!C4``,R_```&-@``T+\```8X``#4OP``!CD`
M`-B_```&.@``W+\```8[``#@OP``!CP``.2_```&/0``Z+\```8^``#LOP``
M!D```/"_```&00``]+\```9"``#XOP``!D,``/2^```'/P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!3@^P(Z+<"``"!P]^>``"+@S0```"%P'0"_]"#Q`A;P_^S!````/^C"```
M``````#_HPP```!H`````.G@____C4PD!(/D\/]Q_%6)Y5>)SU93Z&D"``"!
MPY&>``!1@^PLBT$$B474BT$(B4709:$4````B47DC4704(U%U%!1_Y/\````
MBX,P````@\0,4%#_LX0```!GZ!0P``"+@_````"#Q!"`.``/A!\!``"+@WP`
M``!EBP"`B*("```#BP>-<`.#P`2)=<P]____/P^'?@$``(/L#,'@`E#_D^``
M``"+==2+/XG!B8,\`0``BP:#Q!")`8V#`Z/__XE!!(N#+`$``(E!"(V#!J/_
M_XE!#(/_`0^.6@$``(E-R(U&!(U1$(TTOHUV`(L(@\`$@\($B4K\.<9U\8M-
MR(/'`X/L#(V#R&K__\<$N0````!J`%'_=<Q0_[-``0``_Y,D````@\0@A<`/
MA)@```"#[`S_LT`!``"-?>#_D[@```")^HG&C8._H?__Z#0"``"#Q!"%P`^$
M@P```(/L#/^S0`$``/^3'````(/$$/^3>````(M%Y&4K!10````/A<D```"-
M9?")\%E;7E]=C6'\P_^37````(F#0`$``(7`#X2<````@^P,4/^3C````(N#
M?````&6+$(/$$,:"<@4```#IL?[__X/L#/^S0`$``/^31````(/$$.E1____
MBX,X`0``A<!T$8/L#%#HDQT``(/$$.EB____B?J-@W2A___H?@$``(F#.`$`
M`(7`#X1'____Z]*+1>1E*P44````=2I04(V#;Z'___^S]````%#_D]P```"_
M!````.G`_O__@^P,:@'_DQ`!``#H4RX``&:0D#'M7HGA@^3P4%12Z!@```"!
MPTB<``!J`&H`45;_LQ0!``#H>?W___2+'"3#9I!FD(L<),-FD&:09I!FD&:0
M9I#HX````('"$YP``(V*,`$``(V",`$``#G(=!V+@E@```"%P'0358GE@^P4
M4?_0@\00R<,NC70F`,.-M"8`````Z*````"!PM.;``!5B>53C8HP`0``C8(P
M`0``@^P$*<B)P\'H'\'[`@'8T?AT%(N2:````(72=`J#[`A04?_2@\00BUW\
MR<,NC;0F`````)!5B>53Z%?___^!PW^;``"#[`2`NS`!````=2B+@PP!``"%
MP'02@^P,_[,<`0``_Y,,`0``@\00Z#3____&@S`!```!BUW\R<,NC;0F````
M`.E;____BQ0DPV:09I!FD)!5B<%7Z,H<``"!QQ^;``!64X/L'(E4)`B+A[``
M``"+$(72#X2;````#[8!A,!T!#P]=54Q[8L:A=MT/8E4)`R)V(G3B4PD!(G&
MC;0F`````(/L!%7_="0,5O^7[````(/$$(7`=0:`/"X]=#2+<P2#PP2%]G7:
MB?.#Q!R)V%M>7UW#C;8`````B<T/MD4!@\4!A,!T!#P]=?$IS>N8C78`BU0D
M#(GPB=Z)PXM$)`@IUHU<*P'!_@*),(/$'(G86UY?7<,QV^NQ+HVT)@````"0
M5NCY&P``@<92F@``4X/L?&6+'10```")7"1TB<.-1"044%/_EM````"#Q!"%
MP'4XBU0D'('B`/```('Z`$```'0(@?H`H```=2"#[`AJ`E/_EF0```"#Q!"%
MP`^4P`^VP.L'+HUT)@`QP(M4)&QE*Q44````=0:#Q'1;7L/HSBL``"Z-M"8`
M````C;8`````55=6Z&<;``"!QL"9``!3@>R,````98L=%````(E<)'R)PX7;
M=`6`.P!U)8M$)'QE*P44````#X4]`0``@<2,````6UY?7<,NC;0F`````)"#
M[`Q3_Y9T````B<>#Q!"%P'3(@^P,5_^6D````(/$$(7`#X2X````@'@3+HU0
M$W4/@'H!`'3<+HVT)@````"0@'@3+@^$M@```(E4)`R#[`Q3_Y:<````BU0D
M'(G%B10DB50D'/^6G````(U$!0*)!"3_EKP```")Q5B-AB"A__]:BU0D%%)3
M4&K_:@%5_Y;D````@\08C40D)%!5_Y9L````@\00@_C_=!"+1"0L)0#P```]
M`$```'1E@^P,5?^6H````(/$$(/L#%7_EF````"#Q!#I.?___XVV`````(/L
M#%?_EK0```")'"3_EL@```"#Q!#IX/[__RZ-="8`@'H!+@^%0/___X!Z`@`/
MA/_^___I,?___XVT)@````")Z.B)_O__ZY_H0BH``&:05>CQ&0``@<5"F```
M5XG',<!64X/L.(`Z/66+'10```")7"0HB=,/E,`!PU/_E9P```"#Q!")1"0$
MC50D&(GXZ-S\__^%P`^$!`$``(/L#(G&4/^5G````(M,)!2#Q!`YR`^#R0``
M`(M$)!C!X`*)1"0(BX6P````B00D#[8'A,`/A)H!```\/0^$D@$``(GX#[90
M`8/``832=`6`^CUU\"GXBPPDBW0D"(/L#(M4)!`#,8U$$`)0_Y6\````B0:#
MQ!"%P'1)BPPDBW0D"(L!C4\!BQ0P#[8'B`(\/70=A,!U"NL7C70F`#P]=`\/
MM@&#P@&#P0&(`H3`=>W&`CTQP`^V#`.(3`(!@\`!A,EU\8M$)!QE*P44````
M#X43`0``@\0L6UY?7<,NC;0F`````#'`C;8`````#[84`X@4!H/``832=?+K
MQRZ-M"8`````BX6P````BQ")!"2+,H7V#X3"````,?8NC;0F`````)")\(/&
M`8L,LH7)=?2-!(4,````BXTT`0``A<EU8XE4)`R#[`Q0QX4T`0```0```/^5
MO````(G!@\00A<`/A%W___^-!+4`````@^P$B40D#%"+5"044E&)3"0<_Y78
M````BT0D$(M,)!R#Q!")",=$L00`````B70D&.F,_O__D(/L"%!2_Y4X````
MB<&+1"00@\00B0B%R0^$`?___XT$M0````")1"0(Z\,NC70F`#'`Z7O^__^X
M"````#'VZ5#____H""@``"Z-M"8`````55=64X'L`!```(,,)`"#[##HG1<`
M`(''\I4``(E4)!")QF6A%````(F$)"`0```QP&C_#P``C8<FH?__C6PD)%50
M_Y?4````@\00A<!^$(G#C4#_@'P<&P!U187`=36+AWP```"#[`3_="005F7_
M,/^73````(/$$(N$)!P0``!E*P44````=4*!Q"P0``!;7E]=PXG#+HVT)@``
M``!FD(/L!%-J+U7_E^@```"#Q!"%P'2KBX=\````4U569?\P_Y>H````@\00
MZZ[H,"<``%93Z`GY__^!PS&5``"#[`2-@WSA__^+LWP```!0C8,UH?___[.`
M````4&7_-O^3^````%B-@^"B__]::@!04(V#N'[__U"-@U&A__]09?\V_Y.(
M````@\0D6U[#C70F`.AV%@``!=.4``"#[`R-D'SA__]2C9`UH?___["`````
M4HN0?````&7_,O^0^````(/$',,NC;0F`````(UT)@!55U93@>P`$```@PPD
M`('L`!```(,,)`"#[!PQ[>A.^/__@<-VE```9:$4````B80D#"```#'`_Y,4
M````@^P(C9,QH?__4E"-@V:A__]0:`$0``!J`8UT)"96_Y/D````@\0<:``0
M``"-O"03$```5U;_D]0```"#Q!"%P'@L@^P,B<:-0`%0_Y.\````B<6#Q!"%
MP'04@^P$5E=0_Y.8````QD0U``"#Q!"+A"0,(```92L%%````'4-@<0<(```
MB>A;7E]=P^C#)0``C78`Z2O___\NC;0F`````(UV`%575E.![``0``"##"0`
M@>R<````Z'?W__^!PY^3``"+O"2P$```98LM%````(FL)(P0``"+K"2T$```
MC40D+(E$)!2)PHV#=*'__^A`^/__@^P(:B^)QE?_DSP```"#Q!"%P'0SC8-]
MH?__B?KH_OK__XGXBY0DC!```&4K%10````/A9H!``"!Q)P0``!;7E]=PRZ-
M="8`@^P,5?^3``$``%I9C8N*H?__B4PD%%%0_Y/,````C8N,H?__B<6-@Y6B
M__^#Q!")1"08A>UTEH!]``")3"0<#X3J````C78`A?9T%H/L"%56_Y,(`0``
M@\00A<`/A*<```"#[`Q5_Y.<````B<*-1`7_@\00.<5R$>LC+HUT)@#&``"#
MZ`$YQ70%@#@O=/&#[`Q5_Y.<````B<*#Q!")5"00@^P,5_^3G````(M4)""-
M1`(!@\00/?\/```/APO___^#[`17_W0D)%7_="0H:``0``!J`8VL)*@```!5
M_Y/D````@\08_W0D'%7_DVP```"#Q!"%P'40BT0D/"4`\```/0"```!T3X/L
M"/]T)!1J`/^3S````(G%@\00A<`/A*C^__^`?0``#X49____A?9T!8`^+G00
MN@$```"-JW*A___I5O___X!^`0!TN^OH+HVT)@````"#[`AJ`57_DV0```"#
MQ!"%P'6>B>J-@WVA___H8/G__X/L#%7_DP`!``"#Q!#I4O[__^B)(P``+HVT
M)@````"05N@I$P``@<:"D0``4X/L#(M<)!AJ+U/_EE````"#Q!"%P'0#C5@!
MB5PD$(/$!(GP6U[_H``!```NC;0F`````%575E.![``0``"##"0`@^P<Z.$2
M``"!Q3*1``!EBS44````B;0D#!```(NT)#`0``"%]@^$IP```(`^``^$G@``
M`(/L#%;_E9P```"-2`&#Q!"!^0`0```/A^(```"-7"0,@_D$#X.E````A<D/
MA=T```"-1`/_.<-R#^L2C78`Q@``@^@!.=AT!8`X+W3Q@^P(:B]3_Y50````
M@\00A<!T/CG##X*&````@^P,4_^5``$``(/$$(N4)`P0``!E*Q44````#X6D
M````@<0<$```6UY?7<,NC;0F`````&:0BX0D#!```&4K!10```!U?XV%<J'_
M_XF$)#`0``"!Q!P0``")Z%M>7UW_H``!``"0BU0._(G?B50,"(G!P>D"\Z7I
M3?___RZ-M"8`````9I#&``#I<O___RZ-M"8`````,<#I</___RZ-M"8`````
MD`^V%HA4)`SVP0(/A!/___\/MU0._F:)5`P*Z03____HS"$``"Z-M"8`````
MC70F`%575NAG$0``@<;`CP``4X/L+&6+'10```")7"0<C5PD&(NNL````(V^
MCJ'__XG:B?CH:O3__X7`="^+5"08BT4`C020BU`$B1"%TG3@C78`BU`(@\`$
MB1"%TG7TB=J)^.@[]/__A<!UT8NNL````(V^EZ'__XG:B?CH(O3__X7`="^+
M5"08BT4`C020BU`$B1"%TG3@C78`BU`(@\`$B1"%TG7TB=J)^.CS\___A<!U
MT8NNL````(V^GZ'__XG:B?CHVO/__X7`="^+5"08BT4`C020BU`$B1"%TG3@
MC78`BU`(@\`$B1"%TG7TB=J)^.BK\___A<!UT8NNL````(V^J*'__XG:B?CH
MDO/__X7`="^+5"08BT4`C020BU`$B1"%TG3@C78`BU`(@\`$B1"%TG7TB=J)
M^.AC\___A<!UT8V&KZ'__XN^L````(D$)(L$)(G:Z$;S__^%P'0LBU0D&(L'
MC020BU`$B1"%TG3@BU`(@\`$B1"%TG7TBP0DB=KH&O/__X7`==2+KK````"-
MOK^A__^)VHGXZ`'S__^%P'0VBU0D&(M%`(T$D(M0!(D0A=)TX"Z-M"8`````
M9I"+4`B#P`2)$(72=?2)VHGXZ,OR__^%P'7*C89TH?__B[ZP````B40D!(M$
M)`2)VNBL\O__A<!T,XM4)!B+!XT$D(M0!(D0A=)TWXVV`````(M0"(/`!(D0
MA=)U](M$)`2)VNAY\O__A<!US8V&RZ'__XN^L````(E$)`R+1"0,B=KH6O+_
M_X7`=#&+5"08BP>-!)"+4`2)$(72=-^-="8`BU`(@\`$B1"%TG7TBT0D#(G:
MZ"GR__^%P'7/C8;5H?__B[ZP````B40D"(M$)`B)VN@*\O__A<!T,8M4)!B+
M!XT$D(M0!(D0A=)TWXUT)@"+4`B#P`2)$(72=?2+1"0(B=KHV?'__X7`=<^+
MKK````"-OM^A__^)VHGXZ,#Q__^%P'0UBU0D&(M%`(T$D(M0!(D0A=)TX"Z-
MM"8`````D(M0"(/`!(D0A=)U](G:B?CHB_'__X7`=<N+KK````"-OGVA__^)
MVHGXZ'+Q__^%P'0OBU0D&(M%`(T$D(M0!(D0A=)TX(UV`(M0"(/`!(D0A=)U
M](G:B?CH0_'__X7`==&)VHV&Z:'__^@R\?__A<!T"XG"BT0D".@#]/__B=J-
MAOJA___H%O'__X7`=`V)PHV&#*+__^CE\___B=J-AA>B___H^/#__XG"A<!T
M*XM$)`3HR?/__XM$)!QE*P44````=3.+!"2#Q"R-ECBB__];7E]=Z:?S__^)
MVHV&)Z+__^BZ\/__A<!TS8G"BT0D#.B+\___Z\#HQ!T``(UT)@#H9@T```7#
MBP``@^P<98L5%````(E4)`R-5"0(C8#+H?__Z'GP__^%P'0M#[80@/HP#Y3`
MA-(/E,()T(/P`0^VP(M4)`QE*Q44````=0Z#Q!S#C;8`````,<#KY>A?'0``
M+HVT)@````"-M"8`````4^@J[___@<-2BP``@^P(C40D%%#_="04BX.4````
M:@'_,/^3<````,<$)/\```#_DQ`!```NC;0F`````(UV`%575E.-G"0``/__
M@>P`$```@PPD`#G<=?*#["SHS^[__X'#]XH``(E$)`2)QV6A%````(F$)!P`
M`0`QP&H":@!J`%?_DP0!``"#P/^#TO^)1"08B=>)5"0<P?\?B?XQ\"GP,=(E
M__\``#'Z,?`I\(MT)!@9^HM\)!PIQAG7@\00C6PD%(7_#XBP````C70F`&H`
M5U;_="00_Y,$`0``(="#Q!"#^/\/A+@```"#[`1H"``!`%7_="00_Y-4````
M@\00@_C_='Z#^`=V5(U$!?@YZ'),C14@`0``ZPN-="8`@^@!.>AR.8L,&CD(
M=?*+BR0!```Y2`1UYRGHF0'P$?J+C"0<``$`92L-%````'5S@<0L``$`6UY?
M7<,NC70F`('&``#__X/7_XGPB?HU``#___?2"=`/A53___^X_____XG"Z[N+
MA"0<``$`92L%%````'4N@^P,C8-'HO__4.A<_O__BX0D'``!`&4K!10```!U
M#X/L#(V#.J+__U#H/?[__^B(&P``+HVT)@````!3Z%KM__^!PX*)``"#[`C_
MDZP```"#[`Q0_Y.D````@\00A<!T`HL`@\0(6\.-=@!5Z`$+``"!Q5*)``!7
M5E.#["QEBST4````B7PD'(M\)$"-M5.B__^-5"08B?#H_NW__X7`=`>`.`")
MPW4CBT0D'&4K!10```!U=HGZ@\0LB?!;7E]=Z;;P__^-M@````"#[`Q7_Y6<
M````B40D'(D<)/^5G````(M4)!R-1`("B00D_Y6\````@\0,B<*-A8JA__]3
M4(V%E:+__U=0:O]J`5*)5"0L_Y7D````@\0@BU0D#(M$)!QE*P44````=(SH
MBQH``"Z-M"8`````C78`55=64^A7[/__@<-_B```@>S\````BX0D$`$``(U\
M)"R)^HE$)`QEH10```")A"3L````C8-JHO__QX0DE`````````#'A"2X````
M`````,>$)*``````````B80DC````(V#<J'__XF$))````"-@P6B__^)A"2H
M````C8-OHO__B80DK````(V#(J+__XF$)+````"-@W>B__^)A"2T````C8-[
MHO__B80DF````(V#@*+__XF$))P```"-@W2A__^)1"08Z)7L__^%P'0+@#@`
MB<8/A88$``#_DZP```"#[`Q0_Y.D````@\00A<`/A-L#``"+*(7M#X31`P``
M@^P,5?^3G````(U$``&#Q!"#[`Q0_Y.\````B<8/MD4`@\00B70D"(3`=#V-
MBXFB__^)?"0$B?>)SHVT)@````"#[`P/ML"#Q0%05FK_:@%7@\<"_Y/D````
M#[9%`(/$((3`==R+?"0$C:PDI````(V##*+__^L3+HVT)@````"0BT4$@\4$
MA<!T-HGZZ,_K__^)QH7`=.F`.`!TY.B/[/__A<!TVX/L#%;_DP`!``")QH/$
M$(7`=3@NC;0F`````(VL)(P```"+=0"%]G0B@#X`#X3Q`@``B?#H4NS__X7`
M#X7R````BW4$@\4$A?9UWH/L#%;_DYP```!:_W0D%(G%_Y.<````C:P%!`0`
M`(DL)/^3O````(E$)!2)P8V#CJ+___]T)!A0C8.,H?__B40D(%"-@Y.B__]6
MB<Y0:O]J`5'_D^0```"#Q"AHP`$``%;_DQ@```"#Q!"#^/]U$?^3$````(L`
M@_@1#X73`@``@^P(5_]T)!#_D]````")QH/$$(7`='F#[`S_="00BT0D'/\P
MC8-(H___4#'MBX.4````:@'_,/^3+````(/$((N$).P```!E*P44````#X52
M!```@<3\````B>A;7E]=PXVT)@````"#[`R#Q016_Y,``0``B<:#Q!"%P`^$
MU?[__^GY_O__+HVT)@````"0BT0D/"4`\```/0!````/A7/___^+1"1$B40D
M$/^3K````#E$)!`/A5O___^+1"0\)?\!```]P`$```^%1____X/L#%7_D[P`
M``")^HG%C8->HO__Z`?J__^#Q!"%P`^$/`(``(/L"%"+1"08_S#H7?'__XE$
M)""#Q!"%P`^$'@(``(/L#/]T)!S_DYP```")PH/$$(/X`W9'@^P(C8.<HO__
M4(M$)!R-1!#\B50D*%#_DP@!``"#Q!"%P'4CBU0D'(/Z!`^$\@(``(M$)!"`
M?!#[+P^$XP(``(VT)@````")^HV[RZ'__XGXZ''I__^%P`^$N0$```^V`(3`
M#X2N`0``/#`/A*8!``"-DSBB__^)^(V[X*+__^@C[/___Y,4````5U"-@\"B
M____="00_W0D$%!J_VH!5?^3Y````(V#SJ+__X/$((E$)`SK-F:0_Y,0````
M@S@1=4#_DQ0```"#Q@&#[`Q75E#_="0@_W0D(/]T)"QJ_VH!5?^3Y````(/$
M,(/L"&C``0``5?^3&````(/$$(/X_W2U@^P,_W0D$/^38````(M$)"B)ZNB-
MZ___B2PDZ'7Z__^#Q!#I[?W__RZ-="8`,?;I(?W__Y"-M"28````+HVT)@``
M``"0BP:%P'0:B?KH<^C__X7`=`6`.`!U,HM&!(/&!(7`=>:#[`R-JV.B__]J
M#?^3O````(G&@\00B40D"+A3````Z0?\__^-="8`@^P,@\8$4/^3``$``(/$
M$(7`=*2)Q>F\^___@^P(4/]T)!"+1"0<_S"-@PRC___I/OW__XUT)@"#[`Q0
MZ,?Y__^#Q!"+A"3L````92L%%`````^%E@$``(FT)!`!``"!Q/P```")V%M>
M7UW_H``!``"-M"8`````BT0D#(L`B40D$.G3_?__D(/L"&H`_W0D'/^3*```
M`(/$$(7`#X1`_O__B40D#.B=]___B40D$(E4)!2%T@^()_[__X/`]FH`@]+_
M4E"+3"0848E,)!S_DP0!``"#Q`QJ!HV$),4```!0BTPD&%&)3"0<_Y-4````
M@\00BTPD#(/X!@^%\P```(&\)+T`````0T%##X71_?__9H&\),$```!(10^%
MP?W__VH`BT0D%(M4)!B#P,Z#TO]24%&)3"0<_Y,$`0``@\0,:BB-M"3+````
M5HM,)!A1_Y-4````@\00@_@H#X61````C8/@HO__QH0DZP````!0C8.QHO__
M5O]T)!#_="004&K_:@%5_Y/D````@\0@Z=_]__^+1"0,BU`$A=(/A!7]__^#
M[`Q2B50D'/^3G````(/$$(/X`P^&^_S__X/L"(V+H:+__U&+5"08C40"_%#_
MDP@!``"#Q!"%P`^%U_S__XM4)`R)5"00Z<K\___H91,``(N$).P```!E*P44
M````=>N#[`R-@Z:B__]0Z/;U__^-M@````!55U93Z!?E__^!PS^!``"#[!R-
M?"0(B?IEBS44````B70D#(NS?````&6++@^V162(166-@Z^A___HXN7__X7`
M=`F`.#$/A&4!``#H,/'__V6++HV#WZ+__VH#:@%05?^32````(G%@\00A<!T
M*H/L!(V#X:+__U"+10S_,&7_-O^33````(M%#(L`@\00]D`*0`^%0`$``(V#
MYJ+__VH#:@%09?\V_Y-(````B<6#Q!"%P'0KB?J-@WVA___H7N7__XM5#(L*
MA<`/A/$```"#[`10467_-O^33````(/$$(/L!(V#Z*+__VH!4&7_-O^3(```
M`(V3_:+__X/$#%)09?\V_Y-,````98L&B?K&0&4`C8-TH?__Z`/E__^#Q!")
M@S@!``")QH7`=$2#[`AHP`$``%;_DQ@```"-4`&#Q!"#^@%V"8/X$0^%G@``
M`(M$)`QE*P44````#X6Q````@\0<6UY?7<,NC;0F`````(/L#/^S/`$``.A"
M]___@\00B8,X`0``B<:%P'6?BT0D#&4K!10```!U=X/L#(V#G*/__U#_D]P`
M``"-M@````"`>`$`#X29_O__Z8S^__^0BX,\`0``BQ")R.AQZ?__Z0S___^-
M="8`@^P(4&7_-O^3P````(/$$.FK_O__BU0D#&4K%10```!U%U"+@SP!``!6
M_S"-@\"C__]0_Y/<````Z"H1```NC;0F`````&:05U93Z/CB__^!PR!_``"#
M[!!EBS44````B70D#(MT)""-5"0(C8/+H?__Z-'C__^%P'0;#[80A-(/E,"`
M^C`/E,((T'4)A?9T!8`^`'4:BT0D#&4K!10```!U:X/$$%M>7\.-M@````"#
M[`Q6Z&_M__^)QUA::B]7_Y-0````@\00A<!T`XUX`8/L#%?_DP`!``"-DXZB
M__^#Q`QJ!%)0_Y/L````@\00A<!UHHM$)`QE*P44````=0V#Q!")\%M>7^F:
MY/__Z%40``"+!"3#BS0DPXL\),.++"3#9I!FD)!55U93B<.!['P!``")1"00
MC4PD+&6A%````(F$)&P!```QP"Z-="8`BU2#'`_*B12!@\`!@_@0=>^+3"0P
MBWPD9(U4)#2+="1@BT0D:(E,)`B-C"0T`0``BUPD+(G]B4PD#.L(C70F`(E,
M)`B+"HG'BT(8@\($,<@Q\(GNB?TQV(M<)`C1P(E"-#E4)`QUV8M\)!"+1"0L
MBS>+5Q"+;PB+7PR)5"0<C90"F7F"6HGPBT\$P<`%B?>)7"0(`<*)Z(E,)!0Q
MV(E\)`PAR,')`HEL)!@QV(M<)#`!PHGH,<@A\(MT)`@QZ(VT'IEY@EJ+7"0T
M`<:)T,'`!8V<'9EY@EJ+;"0X`<:)^,'(`HG'B<@Q^"'0P<H",<B-C"F9>8):
MBVPD/`'#B?#!P`4!PXGX,=`A\,'.`C'XC;POF7F"6HML)$`!R(G9P<$%`<B)
MT3'Q(=DQT8V4*IEY@EJ+;"1$`?F)Q\''!<'+`@'YB?<QWR''P<@",?>-M"Z9
M>8):BVPD2`'ZB<_!QP4!^HG'B=@Q^"'(,=B-G"N9>8):BVPD3`'PB=;!Q@4!
M\(G.B?G!S@(Q\2'1,?F-O"^9>8):BVPD4`'9B</!PP4!V8G3B?+!RP(QVB'"
MP<@",?*-M"Z9>8):BVPD5`'ZB<_!QP4!^HG'B=@Q^"'(,=B-G"N9>8):BVPD
M6`'PB=;!Q@4!\(G.B?G!S@(Q\2'1,?F-O"^9>8):BVPD7`'9B</!PP4!V8G3
MB?+!RP(QVB'"P<@",?*-M"Z9>8):BVPD8`'ZB<_!QP4!^HG'B=@Q^"'(,=B-
MG"N9>8):BVPD9`'PB=;!Q@4!\(G.B?G!S@(Q\2'1,?F-O"^9>8):`=F)P\'#
M!0'9B=.)\L'+`C':(<+!R`(Q\HG%B=@!^HG/,>C!QP4AR,')`@'ZBWPD:#'8
MC;0^F7F"6HM\)&P!\(G6P<8%C;P[F7F"6@'PB>XQSHG#(=;!PP4Q[L'*`@'W
MBW0D<`'?B<LQTXVT-9EY@EJ+;"1T(</!R`(QRXV,*9EY@EJ+;"1X`=Z)^\'#
M!0'>B=,QPR'[,=/!SP*-E"J9>8):`<N)\<'!!0'+B<$Q^2'QP<X",<$!T8G:
MP<(%`=&+5"1\C800H>O9;HGZ,?(QVL'+`@'"B<C!P`4!PHN$)(````"-O`>A
MZ]ENB?`QV#'(P<D"`?B)U\''!0'XB<^+C"2$````C;0.H>O9;HG9,?DQT0'Q
MB<;!Q@4!\8G6BY0DB````,'.`HV<$Z'KV6Z)^C'R,<(!VHG+P<@"P<,%`=J)
MPXN$)(P```"-O`>AZ]ENB?`QV#'(P<D"`?B)U\''!0'XB<^+C"20````C;0.
MH>O9;HG9,?DQT0'QB<;!Q@4!\8G6BY0DE````,'.`HV<$Z'KV6Z)^C'R,<+!
MR`(!VHG+P<,%`=J)PXN$))@```"-O`>AZ]ENB?`QV#'(P<D"`?B)U\''!0'X
MB<^+C"2<````C;0.H>O9;HG9,?DQT0'QB<;!Q@4!\8G6BY0DH````,'.`HV<
M$Z'KV6Z)^C'R,<+!R`(!VHG+P<,%`=J)PXN$)*0```"-O`>AZ]ENB?`QV#'(
MP<D"`?B)U\''!0'XB<^+C"2H````C;0.H>O9;HG9,?DQT0'QB<;!Q@4!\8G6
MBY0DK````,'.`HV<$Z'KV6Z)^C'R,<+!R`(!VHG+P<,%`=J)PXN$)+````"-
MO`>AZ]ENB?`QV#'(P<D"`?B)U\''!0'XB<^+C"2T````C;0.H>O9;HG9,?DQ
MT0'QB<;!Q@4!\8G6BY0DN````,'.`HV<$Z'KV6Z)^C'R,<+!R`(!VHG+P<,%
M`=J)PXN$)+P```"-O`>AZ]ENB?`QV#'(P<D"`?B)U\''!0'XB<^+C"3`````
MC;0.H>O9;HG9,?DQT0'QB<;!Q@4!\8G6BY0DQ````,'.`HV<$Z'KV6Z)^C'R
M,<+!R`*)Q0':BX0DR````(G+P<,%`=J-G`>AZ]ENB?`QZ#'(`=B)T\')`L'#
M!0'8B>L)RXG?B>LAUR'+P<H""?N+O"3,````C;0^W+P;CP'SB<;!Q@4!\XG.
M"=:)]XG.(<<AUL'(`@G^B[PDT````(V\/=R\&X\!]XG>P<8%`?>)U@G&B?6)
MUB'=(<;!RP()[HNL)-0```"-C"G<O!N/B=V)PP'.B?D)Z\'!!2'[`<Z)P2'I
M"=F+G"38````C9P:W+P;CXGR`<O!SP*)Z<'"!0GY`=.)ZB'QP<X"(?H)RHN,
M)-P```"-C`C<O!N/B=@!T<'`!0'!B?@)\(G"B?@AVB'PP<L""="+E"3@````
MC905W+P;CP'"B<C!P`4!PHGP"=B)Q8GP(<TAV,')`@GHBZPDY````(V\+]R\
M&X^)W0'XB=<)S<''!2'5`?B)SXG9(?D)Z8NL).@```"-M"[<O!N/B?T!\8G&
MP<8%`?&)UHGZP<X""?4A\B'%P<@"">J+K"3L````C9PKW+P;CP':B<O!PP4!
MVHG#B?`)V(G%B?`AS2'8P<D"">B+K"3P````C;POW+P;CXG=`?B)UPG-P<<%
M(=4!^(G/B=DA^0GIBZPD]````(VT+MR\&X^)_0'QB<;!Q@4!\8G6B?K!S@()
M]2'R(<4)ZHNL)/@```"-G"O<O!N/`=J)R\'(`L'#!0':B<.)\`G8B<6)\"'-
M(=C!R0()Z(NL)/P```"-O"_<O!N/B=T!^(G7"<W!QP4AU0'XB<^)V2'Y">F+
MK"0``0``C;0NW+P;CXG]`?&)QL'&!0'QB=:)^L'.`@GU(?(AQ<'(`@GJBZPD
M!`$``(V<*]R\&X^)Q0':B<O!PP4!VHGS"<.)\"'+(>@)V(N<)`@!``"-G!_<
MO!N/`=B)T\')`L'#!0'8B>L)RXG?B>LAUR'+P<H""?N+O"0,`0``C;0^W+P;
MCP'SB<;!Q@4!\XG."=:)]XG.(<<AUL'(`@G^B[PD$`$``(V\/=R\&X^)U0'^
MB=\)Q<''!2'=P<L"`?Z)UR''">^+K"04`0``C8PIW+P;CXG%`?F)]PG=P<<%
M(?4!^8G'(=\)[XNL)!@!``"-E"K<O!N/BVPD#`'7B<K!S@+!P@4!UXN4)!P!
M``"-E!#6P6+*B=@Q\#'(P<D"`=")^L'"!0'0BY0D(`$``(V<$];!8LJ)\C'*
M,?K!SP(!VHG#P<,%`=J+G"0D`0``C;0>UL%BRHG+,?LQPP'SB=;!Q@4!\XG&
MBX0D*`$``,'.`HV,`=;!8LJ)^#'P,=#!R@(!R(G9P<$%`<B)T8N4)"P!``"-
ME!?6P6+*B?<QSS'?`=>)PL'"!0'7BY0D,`$``,'+`HVT%M;!8LJ)RC':,<(!
M\HG^P<8%`?*)QHN$)#0!``#!S@*-A`'6P6+*B=DQ\3'YP<\"`<&)T,'`!0'!
MBX0D.`$``(V<`];!8LJ)\#'X,=`!V(G+P<,%`=B)TXN4)#P!``#!RP*-E!;6
MP6+*B?XQWC'.P<D"`=:)PL'"!0'6BY0D0`$``(V\%];!8LJ)VC'*,<+!R`(!
M^HGWP<<%`?J)QXN$)$0!``"-A`/6P6+*B<LQ^S'SP<X"`<.)T,'`!0'#BX0D
M2`$``(V,`=;!8LJ)^#'P,=#!R@(!R(G9P<$%`<B)T8N4)$P!``"-E!?6P6+*
MB?<QSS'?P<L"`=>)PL'"!0'7BY0D4`$``(VT%M;!8LJ)RC':,<(!\HG^P<8%
M`?*)QHN$)%0!``#!S@*-A`'6P6+*B=DQ\3'YP<\"`<&)T,'`!0'!BX0D6`$`
M`(V<`];!8LJ)\#'X,=`!V(G+P<,%`=B)TXN4)%P!``#!RP*-E!;6P6+*B?XQ
MWC'.P<D"`=:)PL'"!0'6BY0D8`$``(V\%];!8LJ)VC'*,<+!R`(!^HGWP<<%
M`?J+O"1D`0``C;P[UL%BRHG+,<,Q\\'.`@'[B=?!QP4!^XN\)&@!``"-O#W6
MP6+*`<^)P3'Q,='!R@(!^8G?P<<%`?F+?"00B0^+3"04`=F)3P2+;"08BTPD
M"`'JB5<(C10QB5<,BU0D'`'0B4<0BX0D;`$``&4K!10```!U"X'$?`$``%M>
M7UW#Z&$$``"0Z`;T__\%8W(``(/L&&I@_Y"\````QP`!(T5GQT`$B:O-[\=`
M"/[<NIC'0`QV5#(0QT`0\.'2P\=`%`````#'0!@`````QT!<`````(/$',-5
M5U93Z.?5__^!PP]R``"#[!R+;"0PBWPD.(M,)#2+=1B-!/T``````T44B444
MB?B#U@#!Z!T!\(UU'(E%&(M%7(7`#X47`0``@_\_#XZD````C4?`P>\&B4PD
M-(G+C5?_B40D#,'G!HE4)`@!SV:0BP.#PT")!HM#Q(E&!(M#R(E&"(M#S(E&
M#(M#T(E&$(M#U(E&%(M#V(E&&(M#W(E&'(M#X(E&((M#Y(E&)(M#Z(E&*(M#
M[(E&+(M#\(E&,(M#](E&-(M#^(E&.(M#_(E&/(GHZ/CR__\Y^W64BT0D#(M4
M)`B+3"0TB<?!X@:#X,`IUXU,`4"#_P1R18L!B44<BT0Y_(E$/OR-12"#X/PI
MQBGQ`?Z#YOR#_@1R%(/F_#';BQ09B108@\,$.?-R\V:0B7U<@\0<6UY?7<,N
MC70F`(7_=.P/M@&(11SWQP(```!TW@^W1#G^9HE$/O[KTF:0ND`````IPCGZ
M?TV#[`2-=1Q2`?")5"0048E,)$!0_Y.8````BU0D&(M%7(M,)$0!T(/$$(/X
M0(E%7'67`=&)Z"G7B4PD-.@E\O__BTPD-.F5_O__C70F`(GZZZ^-="8`Z/;Q
M__\%4W```%575E.#[!R+7"0TBW0D,(E$)`2+0Q2+:QB)Q\'H`P_-@^`_#\^)
M?"0(C7L<C5`!QD0#'("-!!>#^C@/CO8```"Y0````"G1=!LQTO;!`0^%@@$`
M`,8$$`#&1!`!`(/"`CG*<O")V.B;\?__C5<$QT,<`````#'`@^+\QT<T````
M`"G7C4\XB=?!Z0+SJXM$)`B):U2)0UB)V.AH\?__BP/!Z!B(!HL#P>@0B$8!
MBP.(9@*+`XA&`P^V0P>(1@0/MT,&B$8%BT,$B&8&BT,$B$8'#[9#"XA&"`^W
M0PJ(1@F+0PB(9@J+0PB(1@L/MD,/B$8,#[=##HA&#8M##(AF#HM##(A&#P^V
M0Q.(1A`/MT,2B$81BT,0B&82BT,0B$83BT0D!(E<)#"#Q!Q;7E]=_Z!@````
M9I"Y.````"G1@_D$<G2-4`3'``````"#XOS'1`C\`````"G0`<B#X/R#^`0/
M@B?___^)P;\$````@^'\B4PD#(U(_\'I`L<"`````(/A`3G'#X,"____A<EU
M7\<$.@````#'1#H$`````(M$)`R#QP@YQW+FZ=_^__\NC;0F`````(7)#X3/
M_O__Q@``]L$"#X3#_O__,=)FB50(_NFW_O__N@$```#&```YR@^";O[__^EY
M_O__C78`QT($`````(M$)`R_"````#G'<HWIAO[__V:09I!FD&:09I!FD&:0
MD.C6[___!3-N``!5B>6#[`C_L!P!``#_=1#_=0S_=0C_D$````#)PV:09I!F
MD&:0D.BF[___!0-N``!5B>6#[`C_D,0``````%.#[`CHO]'__X'#YVT``(/$
M"%O#````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````P````$``@`E<R\E<P`O<')O8R]S96QF+V5X90!$>6YA3&]A9&5R
M.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O
M)6DO)7,`+@!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%
M4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!
M5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,
M7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!
M3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`,0!L<V5E:R!F86EL960`<F5A9"!F
M86EL960`3$1?3$E"4D%265]0051(`%-94U1%30`O=&UP`%1%35!$25(`5$U0
M`%5315(`55-%4DY!344`)3`R>`!P87(M`"5S)7,E<R5S`'!A<FP`+G!A<@!S
M:&]R="!R96%D`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E
M;7`M)74M)74E<P`8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`V
M,P`M90`M+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O
M<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R
M>2!Y;W5R(&]P97)A=&EO;BD*``!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I
M<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D
M:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`````&5V86P@)V5X96,@
M+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R
M=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@
M*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S
M:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,
M15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?
M<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B
M(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I
M>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM
M>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[
M("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I
M>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A
M9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I
M.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P
M*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*
M?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP
M9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.
M?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA
M;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@
M9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H
M*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D[
M"G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@
M)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!
M5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P*
M*3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@
M/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F
M("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB
M<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I
M;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE
M.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y
M<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S
M<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)
M3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N
M86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P
M("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@
M("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE
M>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R
M+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;
M7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*
M;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D[
M"FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'
M24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H
M;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T
M(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D
M(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*
M;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA
M9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN
M9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!
M1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G
M:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T
M7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L
M(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@
M)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O
M=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B
M=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F
M<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ
M93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S
M970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(
M+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P
M.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U
M:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@
M("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F
M(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B
M=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO
M=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C
M<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q
M(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH
M/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@
M7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X
M="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F
M:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64[
M"B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M
M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]
M/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R
M97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T
M.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]
M($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I
M;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I
M;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D
M=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?
M0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@
M=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I
M;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE
M;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP
M;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64[
M"F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@
M(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D
M=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!
M4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E
M<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K
M97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA
M;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE
M(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92![
M"F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M
M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE
M?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z
M:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M
M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@
M+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?
M87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I
M.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D55
M4T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S
M(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2![
M"FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A
M;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R
M:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E
M)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T
M($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`
M861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;
M04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I
M('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@
M>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF
M="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]
M("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*
M?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I
M9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,
M)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P
M96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*
M)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD
M(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ
M)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D
M7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O
M7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q
M=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@
M)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A
M<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N
M)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z
M.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E
M("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@
M;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T
M82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M
M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE
M9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q
M<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR
M96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@
M9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@[
M"GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H
M"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2
M*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#
M86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D[
M"G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A
M<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A
M<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F
M.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@
M86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P
M<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF
M("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ
M7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L
M97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B
M=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R
M8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X
M<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM
M>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H
M87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N
M9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V
M<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@
M:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D
M*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D
M9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@
M;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI
M)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II
M9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@
M)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H
M)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE
M+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M
M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D
M;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E
M<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*
M;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I
M;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY
M("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F
M:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D
M/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^
M("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H
M+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL
M"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S
M,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N
M="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D
M960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D
M;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N
M9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R
M;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P
M87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*
M:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z
M.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D
M9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD
M:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L
M("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A
M8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I
M;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F
M:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.
M)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D
M(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S
M=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I
M;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE
M+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z
M.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I
M;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A
M73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI
M"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA
M;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*
M<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF
M("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A
M="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB
M97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M
M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE
M;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@
M/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.
M5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M
M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO
M=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A
M9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q
M6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN
M72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT
M<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U
M-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL
M97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@
M=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER
M(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P
M(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B
M($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ
M0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z
M.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER
M92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S
M<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R
M97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A
M9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E
M('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER
M92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE
M.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q
M=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I
M<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*
M979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T[
M"F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER
M92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE
M.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/
M.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T
M9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A
M<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA
M<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-
M4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE
M<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM
M>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P
M=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R
M.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M
M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W
M=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D
M14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H
M)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM0
M05)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92![
M"F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S
M(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA
M9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%
M(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#
M2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G
M:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B
M*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C
M:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B
M8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER
M*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`]
M(#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I
M<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R![
M"FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN
M86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE
M*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO
M<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C
M;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I
M9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I
M(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*
M<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'
M3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R
M;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%2
M7U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^
M/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D
M<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%2
M7U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@
M/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E
M='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5]
M(BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R
M96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.
M5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@
M)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L
M:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O
M9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L
M:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D
M<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES
M>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD
M,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD
M97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@
M/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I
M;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D
M("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*
M8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?
M9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-
M17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%
M3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E
M('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%7
M3D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L
M971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,
M14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/
M0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II
M9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*
M?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@
M>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B([
M"GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#
M+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*
M87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*
M=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X[
M"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*
M4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@
M;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R
M(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA
M;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K
M*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`
M.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*
M,3L*7U]%3D1?7PH``$-!0TA%``!P97)L>'-I+F,````!&P,[&`$``"(```"P
M?___8`$``-!___]P#```((+__S0!``!0@___A`$``""$___H`0``L(3__S0"
M```PAO__Z`(``'"(__]H`P``0(G___@#``"@B?__2`0``.")__]L!```L(K_
M_P0%``#`BO__&`4``/",__\8!@``,(W__TP&``"PCO__T`8``+"2__\0!P``
M()/__RP'``!@D___5`<``/"4__\$"```()7__S`(``#PE?__D`@``#"=__\L
M"P``4)____P+```;H/__N`P``!^@___,#```(Z#__^`,```GH/__]`P``#"@
M__\(#0``$*S__TP-``!@K/__:`T``""N__^X#0``0+#___@-``!PL/__&`X`
M`!0``````````7I2``%\"`$;#`0$B`$'"!`````<````Y(#__RP`````````
M%``````````!>E(``7P(`1L,!`2(`0``(````!P```!(?O__(``````."$8.
M#$H/"W0$>``_&CLJ,B0B8````$````#$@?__QP````!!#@B%`D,.#(<#3`X0
MA@1!#A2#!4,.,'\.-$$..$0./$$.0$D.,%D*#A1#PPX00<8.#$''#@A!Q0X$
M1PMT"@X40\,.$$'&#@Q!QPX(0<4.!$$+`$@```"D````,(+__X(`````00X(
MA@),#@R#`T,.B`%2#HP!00Z0`4D.@`%A#H@!0@Z,`4$.D`%)#H`!80H.#$'#
M#@A!Q@X$00L```"P````\````'2"__]^`0```$$."(4"00X,AP-!#A"&!$P.
M%(,%1@Z@`6T*#A1!PPX00<8.#$''#@A!Q0X$2@M##JP!00ZP`4L.H`%'#JP!
M00ZP`4D.H`%Q#JP!00ZP`6D.K`%'#J@!10ZL`4$.L`%!#K0!0@ZX`4(.O`%!
M#L`!20ZH`44.K`%!#K`!20Z@`5@.K`%!#K`!20Z@`4,.K`%!#K`!20Z@`4X.
MK`%!#K`!4@Z@`0!\````I`$``$"#__\X`@```$$."(4"3`X,AP-%#A"&!$$.
M%(,%0PY,5@Y020Y`6@Y,0PY030Y``DT.3$L.4$L.0`)A"@X40<,.$$'&#@Q!
MQPX(0<4.!$D+`F0.3$$.4%4.0%(.1$4.2$4.3$$.4%4.0%<.2$$.3$$.4$\.
M0````(P````D`@```(7__]``````00X(A0)!#@R'`T$.$(8$00X4@P5&#I0@
M1P[$(&4.R"!+#LP@00[0($D.P"!=#L0@1`[(($$.S"!##M`@20[`(%8*#A1!
MPPX00<8.#$''#@A!Q0X$00M/#L0@00[(($(.S"!!#M`@20[`($L.Q"!!#L@@
M00[,($,.T"!)#L`@`$P```"T`@``0(7__UP`````00X(A@)!#@R#`TX.$$T.
M%$P.&$$.'$,.($<.'$<.&$(.'$$.($$.)$<.*$<.+$,.,$D.#$'##@A!Q@X$
M````(`````0#``!0A?__-`````!-#A!'#A1,#AA!#AQ)#B!)#@0`E````"@#
M``!LA?__S0````!!#@B%`D$.#(<#00X0A@1!#A2#!48.E"!*#I1`1PZP0&4.
MN$!'#KQ`00[`0$<.Q$!%#LA`0@[,0$4.T$!)#K1`10ZX0$@.O$!!#L!`20ZP
M0$<.O$!&#L!`2PZP0$<.M$!!#KA`00Z\0$$.P$!.#K!`5@H.%$/##A!!Q@X,
M0<<."$'%#@1!"P`0````P`,``*2%__\%`````````/P```#4`P``H(7__R<"
M````00X(A0)!#@R'`T$.$(8$00X4@P5&#I0@2@ZP(7\.N"%"#KPA0P[`(4D.
ML"%M"@X40<,.$$'&#@Q!QPX(0<4.!$8+0PZ\(4$.P"%'#KPA00ZX(4L.O"%!
M#L`A5PZP(6`.N"%!#KPA00[`(4D.L"%+#KPA00[`(4\.L"%=#KPA00[`(4L.
ML"%'#KPA00[`(5$.L"%.#K0A00ZX(40.O"%!#L`A1`[$(44.R"%"#LPA2`[0
M(4D.N"%$#KPA00[`(4D.L"%7#K@A1`Z\(4(.P"%+#K`A?@ZX(4(.O"%!#L`A
M20ZP(50.O"%!#L`A20ZP(0`P````U`0``-"&__\X`````$$."(8"3`X,@P-#
M#AA&#AQ!#B!)#A!.#@Q#PPX(0<8.!```@`````@%``#<AO__=`$```!!#@B%
M`D$.#(<#00X0A@1!#A2#!48.E"!'#K`@=`Z\($$.P"!,#K`@`D`.N"!"#KP@
M00[`($D.L"!/#KP@00[`($D.L"!:"@X40<,.$$'&#@Q!QPX(0<4.!$L+8PH.
M%$/##A!!Q@X,0<<."$'%#@1'"P``/````(P%``#8A____`,```!!#@B%`D$.
M#(<#00X0A@1,#A2#!4,.0`.X`PH.%$?##A!!Q@X,0<<."$'%#@1%"Q@```#,
M!0``F(O__V$`````30X@`D0*#@1'"P`D````Z`4``.R+__\U`````$$."(,"
M3@X010X41`X82`X<0@X@````K````!`&```$C/__B`$```!!#@B%`D$.#(<#
M00X0A@1!#A2#!4<,`Y2`!$X-!$,.P(`$8@[$@`1"#LB`!$(.S(`$00[0@`1]
M#L"`!%(.Q(`$00[(@`1!#LR`!$0.T(`$2P[`@`1,#L2`!$4.R(`$00[,@`1$
M#M"`!$D.P(`$`E0*#A1!PPX00<8.#$''#@A!Q0X$1@MX"@[,@`1'#M"`!$4+
M4PH.S(`$1P[0@`1%"P`H````P`8``.2,__\M`````$$."(,"3@X020X<00X@
M20X020X(0<,.!````%P```#L!@``Z(S__\4`````00X(A0),#@R'`T$.$(8$
M00X4@P5##D!]"@X40\,.$$'&#@Q!QPX(0<4.!$L+0PY,00Y09PY$20Y(00Y,
M1PY000Y40@Y80@Y<00Y@30Y``)@"``!,!P``6(W__SH'````00X(A0)!#@R'
M`T$.$(8$00X4@P51#I`"`LX.G`)!#J`"20Z0`E4.G`)!#J`"30Z0`D,.G`)!
M#J`"3PZ0`F`.G`)'#J`"00ZD`D(.J`)"#JP"00ZP`E`.D`("2`Z<`D$.H`)+
M#I`"?PZ<`D$.H`)'#IP"1`Z@`F@.I`)!#J@"2PZL`D<.L`)##K0"0@ZX`D(.
MO`)!#L`"20Z8`D4.G`)!#J`"20Z0`ED.F`)!#IP"1`Z@`DL.D`)'#IP"1`Z@
M`D8.I`)'#J@"2@ZL`D(.L`))#I`"6@H.%$/##A!!Q@X,0<<."$'%#@1("T,.
MG`)$#J`"2PZ0`@)9#IP"00Z@`E@.D`)+#I@"00Z<`D8.H`),#I`"2PZ<`D0.
MH`)+#I`"2`Z8`D<.G`)-#J`"20Z0`@)K#I0"00Z8`DH.G`)$#J`"00ZD`D(.
MJ`)"#JP"00ZP`D\.D`)?#IP"00Z@`D$.I`)!#J@"1`ZL`D0.L`)$#K0"0@ZX
M`D(.O`)!#L`"20Z0`D,.F`)%#IP"00Z@`DD.D`)(#IP"1`Z@`EP.D`("10Z<
M`D@.H`)+#I`"50Z<`D0.H`))#I`"3@H.F`)!#IP"1`Z@`D8.I`)/"T,.G`)!
M#J`"2`Z0`F$*#A1#PPX00<8.#$''#@A!Q0X$30M3#I@"0@Z<`D0.H`))#I`"
M9@Z4`D0.F`)!#IP"10Z@`DT.E`)"#I@"2`Z<`D4.H`)-#I`"<`Z4`D\.F`)!
M#IP"00Z@`DT.E`)"#I@"2`Z<`D4.H`))#I`"6`Z4`D<.F`)$#IP"1`Z@`D$.
MI`)"#J@"0@ZL`D$.L`))#I`"5PZ<`D$.H`)-#I`"3`Z8`D<.G`))#J`"20Z0
M`FT.G`)'#J`"````S````.@)``#\D?__%@(```!!#@B%`D$.#(<#00X0A@1!
M#A2#!4X.,`))#C1"#CA!#CQ!#D!+#C!'#C1'#CA%#CQ##D!.#C!2#C1"#CA!
M#CQ##D!+#C!A#C1!#CA!#CQ##D!)#C!##C1(#CA!#CQ##D!/#C1!#CA!#CQ#
M#D!=#C!/#CA%#CQ!#D!,#C!B"@X40<,.$$'&#@Q!QPX(0<4.!$D+0PH./$8.
M0$@.,%P./$<.0$P+:PXX00X\0PY`20XP4PH.-$<..$(./$<.0$8+`'````"X
M"@``3)/__\L`````00X(AP)!#@R&`T$.$(,$3@X@`DT*#A!!PPX,0<8."$''
M#@1'"T,.+$$.,$@.+$$.*$(.+$$.,$D.($H.+$$.,$\.)$(.*$$.+$$.,$D.
M(%0*#A!#PPX,0<8."$''#@1%"P``1````"P+``!8<___30(```!$#`$`21`%
M`G4`01`'`G5\1!`&`G5X$`,"=71,#P-U<`8#9P$*P0P!`$'#0<9!QT'%0PP$
M!$$+$````'0+``!;D___!``````````0````B`L``$N3__\$`````````!``
M``"<"P``.Y/__P0`````````$````+`+```KD___!`````````!`````Q`L`
M`""3___?"P```$$."(4"00X,AP-!#A"&!$$.%(,%2`Z0`P/)"PH.%$'##A!!
MQ@X,0<<."$'%#@1!"P```!@````(#```O)[__U``````30X<0@X@`D`.!`!,
M````)`P``/">__^\`0```$$."(4"00X,AP-!#A"&!$$.%(,%3@XP`R0!"@X4
M0<,.$$'&#@Q!QPX(0<4.!$8+;@XT1`XX1PX\10Y`5@XP`#P```!T#```8*#_
M_Q$"````2PX(A0)!#@R'`T$.$(8$00X4@P5##C`#(P$*#A1!PPX00<8.#$''
M#@A!Q0X$2`L<````M`P``$"B__\G`````$L."(4"0@T%6<4,!`0``!@```#4
M#```4*+__Q8`````2PX(A0)"#04`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
ML",``&`C```!````\P(```$```#^`@``'0```)($```,`````"````T```#X
M4```&0```-B]```;````!````!H```#<O0``'`````0```#U_O]O-`(```4`
M``!L"0``!@```'P#```*````M00```L````0````%0`````````#````Z+X`
M``(````(````%````!$````7````L!$``!$```"`#P``$@```#`"```3````
M"````!X````(````^___;P$```C^__]OX`X``/___V\!````\/__;R(.``#Z
M__]O!0``````````````````````````````````````````````````````
M``#@O0`````````````V(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!`(`````````3````*4$%2+G!M"@````#L8@``1T-#.B`H1TY5
M*2`Q,RXR+C$@,C`R-#`T,3<`1T-#.B`H1TY5*2`Q-"XQ+C$@,C`R-#`U,C(`
M`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92YG
M;G4N<')O<&5R='D`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N
M9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N
M<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H
M9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC
M`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=```````````````````````````
M````````````````````````````````"P````$````"````M`$``+0!```3
M```````````````!`````````!,````'`````@```,@!``#(`0``)```````
M````````!``````````F````!P````(```#L`0``[`$``"@`````````````
M``0`````````.0````<````"````%`(``!0"```@```````````````$````
M`````$<```#V__]O`@```#0"```T`@``2`$```8`````````!`````0```!1
M````"P````(```!\`P``?`,``/`%```'`````0````0````0````60````,`
M```"````;`D``&P)``"U!``````````````!`````````&$```#___]O`@``
M`"(.```B#@``O@````8``````````@````(```!N````_O__;P(```#@#@``
MX`X``*`````'`````0````0`````````?0````D````"````@`\``(`/```P
M`@``!@`````````$````"````(8````)````0@```+`1``"P$0``"`````8`
M```6````!`````@```"/`````0````8`````(````"```"``````````````
M``0`````````B@````$````&````("```"`@```@```````````````0````
M!````)4````!````!@```$`@``!`(```MC``````````````$`````````";
M`````0````8```#X4```^%```!0```````````````0`````````H0````$`
M```"`````&````!@``!N0``````````````$`````````*D````!`````@``
M`'"@``!PH```'`$`````````````!`````````"W`````0````(```",H0``
MC*$``!P-``````````````0`````````P0````X````#````V+T``-B]```$
M```````````````$````!````,T````/`````P```-R]``#<O0``!```````
M````````!`````0```#9````!@````,```#@O0``X+T```@!```'````````
M``0````(````X@````$````#````Z+X``.B^```8`0`````````````$````
M!````.<````!`````P````#`````P```&```````````````!`````````#M
M````"`````,````8P```&,```!0```````````````0`````````\@````$`
M```P`````````!C````V```````````````!`````0````$````#````````
=``````!.P```^P```````````````0``````````
